import django.dispatch

# Behaves like Djangos normal pre-/post_save signals signals with the
# added arguments ``target`` and ``position`` that matches those of
# ``move_to``.
# If the signal is called from ``save`` it'll not be pass position.
node_moved = django.dispatch.Signal(providing_args=[
    'instance',
    'target',
    'position'
])



from django.contrib import admin

from mptt.admin import MPTTModelAdmin, DraggableMPTTAdmin

from myapp.models import Category, Person


class CategoryAdmin(MPTTModelAdmin):
    pass


admin.site.register(Category, CategoryAdmin)
admin.site.register(Person, DraggableMPTTAdmin)
